# Tagenalgo

## Techanical Analysis & Genatic Algorithm
The is a genetic algorithm incorporated with technical analysis indicator to optimize parameters of a strategy. The innovation of the algorithm is  that you can customize your strategy and use the algorithm to optimize the parameters included in the strategy. 

This algorithm provides:

* Optimize parameters of common technical analysis indicators such as **"Relative Strength Indicator"** or **"Simple Moving Average"**.    
* Optimize parameters of combined technical analysis indicators. E.g. **"Relative Strength Indicator"** + **"Simple Moving Average"**.
* Optimize parameters of customized strategy. E.g. **"Relative Strength Indicator"** + **"self-defined stop loss mechanism"**.

## Installation
```python
pip install tagenalgo
```